@@ -139,7 +139,7 @@ static HEADER *maildir_parse_message(int magic, const char *fname, int is_old)
   if ((f = fopen (fname, "r")) != NULL)
   {
     h = mutt_new_header();
-    h->env = mutt_read_rfc822_header (f, h, 0, 0);
+    h->env = mutt_read_rfc822_header (f, h, 0);
 
     fstat (fileno (f), &st);
     fclose (f);
@@ -613,8 +613,7 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
   if ((dest = mx_open_new_message (ctx, h, 0)) == NULL)
     return -1;
 
-  if ((rc = mutt_copy_message (dest->fp, ctx, h, 
-	       M_CM_UPDATE, CH_UPDATE | CH_UPDATE_LEN)) == 0)
+  if ((rc = mutt_copy_message (dest->fp, ctx, h, M_CM_UPDATE, CH_UPDATE | CH_UPDATE_LEN)) == 0)
   {
     snprintf (oldpath, _POSIX_PATH_MAX, "%s/%s", ctx->path, h->path);
     strfcpy  (partpath, h->path, _POSIX_PATH_MAX);
