@@ -1,6 +1,5 @@
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -66,29 +65,31 @@
 
 #ifdef DL_STANDALONE
 
-static int invoke_dotlock (const char *path, int flags, int retry)
+static int invoke_dotlock(const char *path, int flags, int retry)
 {
   char cmd[LONG_STRING + _POSIX_PATH_MAX];
-  char f[SHORT_STRING + _POSIX_PATH_MAX];
   char r[SHORT_STRING];
+  char *f;
   
-  if (flags & DL_FL_RETRY)
-    snprintf (r, sizeof (r), "-r %d ", retry ? MAXLOCKATTEMPT : 0);
+  if(flags & DL_FL_RETRY)
+    snprintf(r, sizeof(r), "-r %d ", retry ? MAXLOCKATTEMPT : 0);
   
-  mutt_quote_filename (f, sizeof (f), path);
+  f = mutt_quote_filename(path);
   
-  snprintf (cmd, sizeof (cmd),
-	    "%s %s%s%s%s%s%s%s",
-	    NONULL (MuttDotlock),
-	    flags & DL_FL_TRY ? "-t " : "",
-	    flags & DL_FL_UNLOCK ? "-u " : "",
-	    flags & DL_FL_USEPRIV ? "-p " : "",
-	    flags & DL_FL_FORCE ? "-f " : "",
-	    flags & DL_FL_UNLINK ? "-d " : "",
-	    flags & DL_FL_RETRY ? r : "",
-	    f);
+  snprintf(cmd, sizeof(cmd),
+	   "%s %s%s%s%s%s%s%s",
+	   DOTLOCK,
+	   flags & DL_FL_TRY ? "-t " : "",
+	   flags & DL_FL_UNLOCK ? "-u " : "",
+	   flags & DL_FL_USEPRIV ? "-p " : "",
+	   flags & DL_FL_FORCE ? "-f " : "",
+	   flags & DL_FL_UNLINK ? "-d " : "",
+	   flags & DL_FL_RETRY ? r : "",
+	   f);
   
-  return mutt_system (cmd);
+  FREE(&f);
+
+  return mutt_system(cmd);
 }
 
 #else 
@@ -101,11 +102,12 @@ static int dotlock_file (const char *path, int retry)
 {
   int r;
   int flags = DL_FL_USEPRIV | DL_FL_RETRY;
-
-  if (retry) retry = 1;
+  
+  if(retry) retry = 1;
 
 retry_lock:
-  if ((r = invoke_dotlock(path, flags, retry)) == DL_EX_EXIST)
+  mutt_clear_error();
+  if((r = invoke_dotlock(path, flags, retry)) == DL_EX_EXIST)
   {
     if (!option (OPTNOCURSES))
     {
@@ -117,7 +119,6 @@ retry_lock:
       {
 	flags |= DL_FL_FORCE;
 	retry--;
-	mutt_clear_error ();
 	goto retry_lock;
       }
     } 
@@ -295,12 +296,12 @@ void mx_unlink_empty (const char *path)
 {
   int fd;
 #ifndef USE_DOTLOCK
-  struct stat sb;
+  char b;
 #endif
 
   if ((fd = open (path, O_RDWR)) == -1)
     return;
-
+  
   if (mx_lock_file (path, fd, 1, 0, 1) == -1)
   {
     close (fd);
@@ -310,12 +311,11 @@ void mx_unlink_empty (const char *path)
 #ifdef USE_DOTLOCK
   invoke_dotlock (path, DL_FL_UNLINK, 1);
 #else
-  if (fstat (fd, &sb) == 0 && sb.st_size == 0)
+  if  (read (fd, &b, 1) != 1)
     unlink (path);
 #endif
 
   mx_unlock_file (path, fd, 0);
-  close (fd);
 }
 
 /* try to figure out what type of mailbox ``path'' is
@@ -729,14 +729,13 @@ static int sync_mailbox (CONTEXT *ctx)
       
 #ifdef USE_IMAP
     case M_IMAP:
-      /* extra argument means EXPUNGE */
-      rc = imap_sync_mailbox (ctx, 1);
+      rc = imap_sync_mailbox (ctx);
       break;
 #endif /* USE_IMAP */
   }
 
 #if 0
-  if (!ctx->quiet && !ctx->shutup && rc == -1)
+  if (!ctx->quiet && rc == -1)
     mutt_error ( _("Could not synchronize mailbox %s!"), ctx->path);
 #endif
   
@@ -799,9 +798,6 @@ int mx_close_mailbox (CONTEXT *ctx)
     }
     mutt_expand_path (mbox, sizeof (mbox));
 
-#ifdef USE_IMAP
-    if (!mx_is_imap (ctx->path))
-#endif
     if (isSpool)
     {
       snprintf (buf, sizeof (buf), _("Move read messages to %s?"), mbox);
@@ -820,7 +816,7 @@ int mx_close_mailbox (CONTEXT *ctx)
   }
 
 #ifdef USE_IMAP
-  /* IMAP servers manage the OLD flag themselves */
+  /* IMAP servers managed the OLD flag themselves */
   if (ctx->magic != M_IMAP)
 #endif
   if (option (OPTMARKOLD))
@@ -865,43 +861,30 @@ int mx_close_mailbox (CONTEXT *ctx)
     return 0;
   }
   
-#ifdef USE_IMAP
-  /* allow IMAP to preserve the deleted flag across sessions */
-  if (ctx->magic == M_IMAP)
+  if (!purge)
   {
-    if (imap_sync_mailbox (ctx, purge) == -1)
-      return -1;
-    if (ctx->magic == M_IMAP && !purge)
-      mutt_message (_("%d kept."), ctx->msgcount);
+    for (i = 0; i < ctx->msgcount; i++)
+      ctx->hdrs[i]->deleted = 0;
+    ctx->deleted = 0;
   }
+
+  if (ctx->changed || ctx->deleted)
+  {
+    if (sync_mailbox (ctx) == -1)
+      return (-1);
+  }
+
+  if (move_messages)
+    mutt_message (_("%d kept, %d moved, %d deleted."),
+		  ctx->msgcount - ctx->deleted, read_msgs, ctx->deleted);
   else
-#endif
-  {
-    if (!purge)
-    {
-      for (i = 0; i < ctx->msgcount; i++)
-        ctx->hdrs[i]->deleted = 0;
-      ctx->deleted = 0;
-    }
+    mutt_message (_("%d kept, %d deleted."),
+		  ctx->msgcount - ctx->deleted, ctx->deleted);
 
-    if (ctx->changed || ctx->deleted)
-    {
-      if (sync_mailbox (ctx) == -1)
-        return -1;
-    }
-
-    if (move_messages)
-      mutt_message (_("%d kept, %d moved, %d deleted."),
-        ctx->msgcount - ctx->deleted, read_msgs, ctx->deleted);
-    else
-      mutt_message (_("%d kept, %d deleted."),
-        ctx->msgcount - ctx->deleted, ctx->deleted);
-
-    if (ctx->msgcount == ctx->deleted &&
-        (ctx->magic == M_MMDF || ctx->magic == M_MBOX) &&
-        !mutt_is_spool(ctx->path) && !option (OPTSAVEEMPTY))
-      mx_unlink_empty (ctx->path);
-  }
+  if (ctx->msgcount == ctx->deleted &&
+      (ctx->magic == M_MMDF || ctx->magic == M_MBOX) &&
+      !mutt_is_spool(ctx->path) && !option (OPTSAVEEMPTY))
+    mx_unlink_empty (ctx->path);
 
   mx_fastclose_mailbox (ctx);
 
@@ -995,7 +978,6 @@ void mx_update_tables(CONTEXT *ctx, int committing)
 int mx_sync_mailbox (CONTEXT *ctx)
 {
   int rc, i;
-  int purge = 1;
 
   if (ctx->dontwrite)
   {
@@ -1028,40 +1010,22 @@ int mx_sync_mailbox (CONTEXT *ctx)
     snprintf (buf, sizeof (buf), ctx->deleted == 1
 	     ? _("Purge %d deleted message?") : _("Purge %d deleted messages?"),
 	      ctx->deleted);
-    if ((purge = query_quadoption (OPT_DELETE, buf)) < 0)
+    if ((rc = query_quadoption (OPT_DELETE, buf)) < 0)
       return (-1);
-    else if (purge == M_NO)
+    else if (rc == M_NO)
     {
       if (!ctx->changed)
 	return 0; /* nothing to do! */
-#ifdef USE_IMAP
-      /* let IMAP servers hold on to D flags */
-      if (ctx->magic != M_IMAP)
-#endif
-      {
-        for (i = 0 ; i < ctx->msgcount ; i++)
-          ctx->hdrs[i]->deleted = 0;
-        ctx->deleted = 0;
-      }
+      for (i = 0 ; i < ctx->msgcount ; i++)
+	ctx->hdrs[i]->deleted = 0;
+      ctx->deleted = 0;
     }
   }
 
-#ifdef USE_IMAP
-  if (ctx->magic == M_IMAP)
-    rc = imap_sync_mailbox (ctx, purge);
-  else
-#endif
-  rc = sync_mailbox (ctx);
-  if (rc == 0)
+  if ((rc = sync_mailbox (ctx)) == 0)
   {
-#ifdef USE_IMAP
-    if (ctx->magic == M_IMAP && !purge)
-      mutt_message (_("%d kept."), ctx->msgcount);
-    else
-#endif
     mutt_message (_("%d kept, %d deleted."), ctx->msgcount - ctx->deleted,
-      ctx->deleted);
-
+		  ctx->deleted);
     sleep (1); /* allow the user time to read the message */
 
     if (ctx->msgcount == ctx->deleted &&
@@ -1073,12 +1037,8 @@ int mx_sync_mailbox (CONTEXT *ctx)
       return 0;
     }
 
-    /* if we haven't deleted any messages, we don't need to resort */
-    if (purge)
-    {
-      mx_update_tables(ctx, 1);
-      mutt_sort_headers (ctx, 1); /* rethread from scratch */
-    }
+    mx_update_tables(ctx, 1);
+    mutt_sort_headers (ctx, 1); /* rethread from scratch */
   }
 
   return (rc);
@@ -1179,39 +1139,15 @@ MESSAGE *mx_open_new_message (CONTEXT *dest, HEADER *hdr, int flags)
 }
 
 /* check for new mail */
-int mx_check_mailbox (CONTEXT *ctx, int *index_hint, int lock)
+int mx_check_mailbox (CONTEXT *ctx, int *index_hint)
 {
-  int rc;
-
   if (ctx)
   {
-    if (ctx->locked) lock = 0;
-
     switch (ctx->magic)
     {
       case M_MBOX:
       case M_MMDF:
-
-	if (lock)
-	{
-	  mutt_block_signals ();
-	  if (mbox_lock_mailbox (ctx, 0, 0) == -1)
-	  {
-	    mutt_unblock_signals ();
-	    return M_LOCKED;
-	  }
-	}
-	
-	rc = mbox_check_mailbox (ctx, index_hint);
-
-	if (lock)
-	{
-	  mutt_unblock_signals ();
-	  mbox_unlock_mailbox (ctx);
-	}
-	
-	return rc;
-
+	return (mbox_check_mailbox (ctx, index_hint));
 
       case M_MH:
       case M_MAILDIR:
